@@ -12,15 +12,15 @@ the generated changes.
 import argparse
 import json
 import os
-import subprocess
 import statistics
+import subprocess
 import sys
 
 script_dir = os.path.dirname(os.path.abspath(__file__))
 root_dir = os.path.dirname(os.path.dirname(script_dir))
 
 sys.path.insert(0, root_dir)
-from tools import utils, shared
+from tools import utils
 
 
 def run(cmd, **args):
@@ -79,7 +79,7 @@ def main():
       print('tree is not clean')
       return 1
 
-    subprocess.check_call([shared.bat_suffix(os.path.join('test', 'runner')), '--rebaseline', 'codesize'], cwd=root_dir)
+    subprocess.check_call([utils.bat_suffix(os.path.join('test', 'runner')), '--rebaseline', 'codesize'], cwd=root_dir)
 
   output = run(['git', 'status', '-uno', '--porcelain'])
   filenames = []
